Struct syntax::ext::base::SyntaxEnvUnstable
[-] [+]
[src]
pub struct SyntaxEnv {
// some fields omitted
}In order to have some notion of scoping for macros, we want to implement the notion of a transformation environment.
This environment maps Names to SyntaxExtensions.